@@ -38,7 +38,8 @@ Depends:
  make,
  ${dep},
 Restrictions:
- superficial,${flaky}${skippable}
+ superficial,
+ allow-stderr,${flaky}${skippable}
 
 EoF
 }
